@@ -66,21 +66,68 @@ no warnings 'redefine';
 sub new
 {
     my $this = shift( @_ );
-    my $dt   = shift( @_ );
-    if( Scalar::Util::blessed( $dt ) )
+    my $dt;
+    # Module::Generic::DateTime->new( $datetime_object );
+    # Module::Generic::DateTime->new( $datetime_object, $hash_ref_of_options );
+    # Module::Generic::DateTime->new( $datetime_object, %hash_of_options );
+    # Module::Generic::DateTime->new( $datetime_object, %hash_of_options );
+    # Module::Generic::DateTime->new( $hash_ref_of_options );
+    # Module::Generic::DateTime->new( %hash_of_options );
+    if( ( 
+            ( @_ % 2 ) && 
+            (
+                ( scalar( @_ ) == 1 && ref( $_[0] ) ne 'HASH' ) || 
+                scalar( @_ ) > 1
+            )
+        ) || 
+        ( scalar( @_ ) == 2 && ref( $_[1] ) eq 'HASH' ) )
     {
-        if( !$dt->isa( 'DateTime' ) )
+        $dt = shift( @_ );
+    }
+    my $opts = $this->_get_args_as_hash( @_ );
+    
+    if( defined( $dt ) && length( $dt ) )
+    {
+        if( Scalar::Util::blessed( $dt ) )
         {
-            return( $this->error( "Object provided is not a DateTime object." ) );
+            if( !$dt->isa( 'DateTime' ) )
+            {
+                return( $this->error( "Object provided is not a DateTime object." ) );
+            }
+        }
+        else
+        {
+            return( $this->error( "First argument provided, among the odd number of parameters received, is not a DateTime object." ) );
         }
     }
-    elsif( !defined( $dt ) || !length( $dt ) )
+    else
     {
-        my $fmt = DateTime::Format::Strptime->new(
-            pattern => "%FT%T%z",
-            locale => "en_GB",
-        );
-        $dt = DateTime->now( formatter => $fmt );
+        try
+        {
+            if( !exists( $opts->{formatter} ) )
+            {
+                $opts->{formatter} = DateTime::Format::Strptime->new(
+                    pattern => "%FT%T%z",
+                    locale => "en_GB",
+                );
+            }
+            $dt = DateTime->now( %$opts );
+        }
+        catch( $e where { /Cannot[[:blank:]\h]+determine[[:blank:]\h]+local[[:blank:]\h]+time[[:blank:]\h]+zone/i } )
+        {
+            warn( "Warning: Your system is missing key timezone components. Module::Generic::DateTime is reverting to UTC instead of local time zone." );
+            $opts->{time_zone} = 'UTC';
+            $today = DateTime->now( %$opts );
+            my $dt_fmt = DateTime::Format::Strptime->new(
+                pattern => '%FT%T%z',
+                locale => 'en_GB',
+            );
+            $today->set_formatter( $dt_fmt );
+        }
+        catch( $e )
+        {
+            return( $this->error( "Error while creating a DateTime object: $e" ) );
+        }
     }
     return( bless( { dt => $dt->clone } => ( ref( $this ) || $this ) )->init( @_ ) );
 }
